import { LocalNotifications, } from './local-notifications.shared';
/* ========================================================================== *
 * DEBUGGING                                                                  *
 * ========================================================================== */
let debugEnabled = false; // default, no debug
export function debug(...args) {
    if (debugEnabled) {
        const ts = new Date().toISOString().substr(11, 12);
        console.log('[LocalNotifications]', ts, ...args);
    }
}
/* ========================================================================== *
 * MAIN LOCAL NOTIFICATIONS ABSTRACTION                                       *
 * ========================================================================== */
export class AbstractLocalNotifications extends LocalNotifications {
    constructor() {
        super();
        this._handers = new Set();
        this._handler = (notification) => {
            this._handers.forEach((handler) => {
                try {
                    handler(notification);
                }
                catch (error) {
                    console.log('Error handling local notification', notification.id, error);
                }
            });
        };
    }
    /* ------------------------------------------------------------------------ *
     | DEBUGGING INSTRUMENTATION                                                |
     * ------------------------------------------------------------------------ */
    /** Enable/disable debugging */
    static set debugEnabled(enabled) {
        debugEnabled = !!enabled;
    }
    /** Check status of debugging flag */
    static get debugEnabled() {
        return debugEnabled;
    }
    /* ------------------------------------------------------------------------ *
     | IMPLEMENTED METHODS                                                      |
     * ------------------------------------------------------------------------ */
    schedule(notification, when) {
        if (typeof when === 'number') {
            if (when > 0)
                return this.scheduleNative(notification, when);
            else
                return Promise.resolve();
        }
        if (when instanceof Date) {
            const seconds = Math.round((when.getTime() - Date.now()) / 1000);
            if (seconds > 0)
                return this.scheduleNative(notification, seconds);
            else
                return Promise.resolve();
        }
        return Promise.reject(new TypeError('LocalNotifications.schedule() must be called with number or date'));
    }
    /* ------------------------------------------------------------------------ *
     | EVENTS                                                                   |
     * ------------------------------------------------------------------------ */
    on(event, handler) {
        if (typeof handler !== 'function')
            throw new Error('Handler must be a function');
        if (event != 'localNotification')
            return this;
        this._handers.add(handler);
        return this;
    }
    once(event, handler) {
        // Wrap the handler ensuring the wrapper is removed after invocation
        const wrapper = (notification) => {
            try {
                handler(notification);
            }
            finally {
                this.off('localNotification', wrapper);
            }
        };
        // Enable enable dispatching on the wrapper
        this.on('localNotification', wrapper);
        // All done
        return this;
    }
    off(event, handler) {
        if (event != 'localNotification')
            return this;
        this._handers.delete(handler);
        return this;
    }
}
//# sourceMappingURL=local-notifications.abstract.js.map